#!/bin/bash

install_nginx_to_PC="no"
change_to_actual_IP_address="no"
open_Activation_program="no"

# You must have the superuser permissions to run the current script
if [ "$EUID" -ne 0 ]
	then echo "Please run as root"
	exit
fi

read -p "Do you want to install the NGINX web server and setup your environment. (yes/no)? : " install_nginx_to_PC

echo " "
echo The default localhost IP in /var/www/ws_rtsp_proxy/index.html allows to open webpage and watch stream only on localhost PC
echo An actual IP address allows to open webpage and watch stream in local or global network

local_ip_adress=$(ip addr | sed -En 's/127.0.0.1//;s/.*inet (addr:)?(([0-9]*\.){3}[0-9]*).*/\2/p' | head -n 1)
 
read -p "Do you want to replace the localhost to $local_ip_adress adress in www/ws_rtsp_proxy/index.html (yes/no)? :" change_to_actual_IP_address

echo " "
echo To get a free key to activate a free license, you need to go to your personal account on streamedian.com
echo and click the Try it! button in the license table
echo The free key will be added in your account and will be available in the Activation program
echo !License should be activated for localhost or $local_ip_adress : where the web page with player is deployed

read -p "Do you want to run an Activation program after installation to make an license for $local_ip_adress address of your PC (yes/no)? :"  open_Activation_program


#check install_nginx_to_PC
if [ "$install_nginx_to_PC" = "yes" ] || [ "$install_nginx_to_PC" = "y" ]; then
	echo Installing the NGINX web server and setup your environment.
	# You must have the superuser permissions to run the current script
	if [ "$EUID" -ne 0 ]
	  then echo "Please run as root"
	  exit
	fi

	if [ -x "$(command -v dnf)" ]
	then
	  package_manager=dnf
	  semanage_package=policycoreutils-python-utils
	elif [ -x "$(command -v yum)" ]
	then
	  package_manager=yum
	  semanage_package=policycoreutils-python
	  # Add Nginx repository
	  ${package_manager} install -y epel-release
	else
	  echo "Error: No package manager discovered."
	  exit 1
	fi

	${package_manager} update -y

	# Create a folder for NGINX configuration files
	mkdir -p -m0755 /etc/nginx/conf.d/
	# Copy our configuration file to the folder
	cp -rp /usr/share/wsp/nginx/ws_rtsp_proxy_stream.conf /etc/nginx/conf.d/

	# Install the NGINX web server
	${package_manager} install -y nginx

	if [ $? -ne 0 ]
	then
	  echo "Error: to install NGINX."
	  exit 1
	fi

	# Open port 8088
	firewall-cmd --add-port=8088/tcp --permanent
	firewall-cmd --permanent --zone=public --add-service=http

	# And reload the firewall
	firewall-cmd --reload

	if [ $? -ne 0 ]
	then
	  echo "Error: to reload the firewall."
	  exit 1
	fi

	# Check if selinux was installed
	if [ ! -x "$(command -v semanage)" ]
	then
	  # Okay, install it
	  ${package_manager} install -y ${semanage_package}

	  if [ $? -ne 0 ]
		then
		  echo "Error: to install selinux."
		  exit 1
	  fi
	fi

	# Add selinux permission to a new nginx port:
	semanage port -a -t http_port_t -p tcp 8088
	setsebool httpd_can_network_connect on -P

	if [ $? -ne 0 ]
	then
	  echo "Error: to set bool for httpd_can_network_connect."
	  exit 1
	fi

	systemctl stop nginx >/dev/null
	systemctl enable nginx >/dev/null
	systemctl start nginx

	if [ $? -ne 0 ]
	then
	  echo "Error: to start nginx."
	  exit 1
	fi
	
	echo "Done Installation the NGINX web server"
fi


#check change_to_actual_IP_address for web
if [ "$change_to_actual_IP_address" = "yes" ] || [ "$change_to_actual_IP_address" = "y" ]; then
	path_to="/var/www/ws_rtsp_proxy/index.html"
	
	if [ -e ${path_to} ]; then

		old_string="localhost:8088"
		
		#local_ip_adress=$(ip addr | sed -En 's/127.0.0.1//;s/.*inet (addr:)?(([0-9]*\.){3}[0-9]*).*/\2/p')
		
		new_string="${local_ip_adress}:8088"
		sed -i -- "s/${old_string}/${new_string}/g" "${path_to}"
		echo "from ${old_string} to ${new_string} in  ${path_to}"
	else
		echo "${path_to} file not found"
    fi
	
	path_to="/etc/nginx/conf.d/ws_rtsp_proxy_stream.conf"
	
	if [ -e ${path_to} ]; then
		echo "${path_to} exist changing IP"
		
		old_string="localhost 127.0.0.1"		
		new_string="${local_ip_adress}"
		sed -i -- "s/${old_string}/${new_string}/g" "${path_to}"
		echo "from ${old_string} to ${new_string} in  ${path_to}"
		
		systemctl stop nginx >/dev/null
		systemctl start nginx

		if [ $? -ne 0 ]
		then
			echo "Error: to start nginx."
			exit 1
		fi
	else
		echo "${path_to} file not found"
    fi
fi

#check open_Activation_program
if [ "$open_Activation_program" = "yes" ] || [ "$open_Activation_program" = "y" ]; then
	if [ -e "/usr/bin/wsp/activation_app" ]; then
		/usr/bin/wsp/activation_app
	else
		echo /usr/bin/wsp/activation_app not found
    fi	
fi

exit 0

# If you would like to cancel all these changes, please use the following commands:

#systemctl stop nginx
#rm -rf /etc/nginx/conf.d/ws_rtsp_proxy_stream.conf
#rmdir -p --ignore-fail-on-non-empty /etc/nginx/conf.d/
#${package_manager} remove nginx
#firewall-cmd --remove-port=8088/tcp --permanent
#firewall-cmd --reload
#semanage port -d -t http_port_t -p tcp 8088
#setsebool httpd_can_network_connect off -P
#${package_manager} remove ${semanage_package}
